@@ -16,12 +16,12 @@ pub use types::boolean::BoolDecompressor;
 
 pub use constants::MAX_ENTRIES;
 
+mod bits;
 mod constants;
 mod huffman;
 mod prefix;
 mod utils;
 pub mod bit_reader;
-pub mod bits;
 pub mod compressor;
 pub mod decompressor;
 pub mod errors;
