@@ -1,24 +1,31 @@
-use crate::types::{NumberLike, DataType};
+use std::cmp::Ordering;
 use std::convert::TryInto;
+
 use crate::compressor::Compressor;
 use crate::decompressor::Decompressor;
+use crate::types::{DataType, NumberLike};
+
+impl NumberLike for i32 {
+  fn num_eq(&self, other: &Self) -> bool {
+    self.eq(other)
+  }
+
+  fn num_cmp(&self, other: &Self) -> Ordering {
+    self.cmp(other)
+  }
+}
 
 pub struct I32DataType {}
 
-impl NumberLike for i32 {}
-
 impl DataType<i32> for I32DataType {
   const HEADER_BYTE: u8 = 3;
   const BIT_SIZE: usize = 32;
-  const ZERO: i32 = 0;
 
-  #[inline(always)]
-  fn u64_diff(upper: i32, lower: i32) -> u64 {
+  fn offset_diff(upper: i32, lower: i32) -> u64 {
     (upper as i64 - lower as i64) as u64
   }
 
-  #[inline(always)]
-  fn add_u64(lower: i32, off: u64) -> i32 {
+  fn add_offset(lower: i32, off: u64) -> i32 {
     if lower >= 0 {
       (lower as u64 + off) as i32
     } else if off == 0 {
