@@ -1,24 +1,31 @@
-use crate::types::{NumberLike, DataType};
+use std::cmp::Ordering;
 use std::convert::TryInto;
+
 use crate::compressor::Compressor;
 use crate::decompressor::Decompressor;
+use crate::types::{DataType, NumberLike};
+
+impl NumberLike for u64 {
+  fn num_eq(&self, other: &Self) -> bool {
+    self.eq(other)
+  }
+
+  fn num_cmp(&self, other: &Self) -> Ordering {
+    self.cmp(other)
+  }
+}
 
 pub struct U64DataType {}
 
-impl NumberLike for u64 {}
-
 impl DataType<u64> for U64DataType {
   const HEADER_BYTE: u8 = 2;
   const BIT_SIZE: usize = 64;
-  const ZERO: u64 = 0;
 
-  #[inline(always)]
-  fn u64_diff(upper: u64, lower: u64) -> u64 {
+  fn offset_diff(upper: u64, lower: u64) -> u64 {
     upper - lower
   }
 
-  #[inline(always)]
-  fn add_u64(lower: u64, off: u64) -> u64 {
+  fn add_offset(lower: u64, off: u64) -> u64 {
     lower + off
   }
 
